import argparse
import os
import re

from roverio.constants import DIRS_TO_IGNORE


class ScoutCLI():
    def __init__(self):
        parser = argparse.ArgumentParser(
            description='Scout searches through a directory for any string of text you specify.'
        )
        parser.add_argument(
            '-p',
            '--path',
            required=True,
            help='Where Scout will search for the string specified in each file.'
        )
        parser.add_argument(
            '-s',
            '--search',
            required=True,
            help='The string to search for in each file of a path.'
        )
        parser.parse_args(namespace=self)

    def run(self):
        Scout.main(
            path=self.path,
            search=self.search,
        )


class Scout():
    @staticmethod
    def main(path, search):
        """Run the tool and print to console
        """
        print('\n##################\nROVER IO - SCOUT\n##################\n')
        print('Rover IO Scout found the following for your search query:\n')
        messages = Scout.search_for_string(path, search)
        for message in messages:
            print(message)

    @staticmethod
    def search_for_string(path, search):
        """Iterate over each file and directory and build a list of results
        containing the specified string
        """
        regex_pattern = re.compile(search)

        # Scout for the search query in all subdirectories of the one specified
        scout_files = []
        for root, dirs, files in os.walk(path, topdown=True):
            dirs[:] = [directory for directory in dirs if directory not in DIRS_TO_IGNORE]
            for filename in files:
                filepath = os.path.join(root, filename)

                # Open each file and print the findings
                with open(filepath, 'r') as single_file:
                    for line_number, line in enumerate(single_file, 1):
                        data = regex_pattern.findall(line)
                        for search in data:
                            message = f'File: {filepath}\nSearch: {line.strip()}\nLine: {line_number}\n'
                            scout_files.append(message)
        return scout_files


def main():
    ScoutCLI().run()


if __name__ == '__main__':
    main()



DIRS_TO_IGNORE = [
    '__pycache__',
    '.git',
    '.pytest_cache',
    'build',
    'dist',
    'htmlcov',
    'node_modules',
    'vendor',
]

FILES_TO_IGNORE = [
    '.bmp'
    '.eot',
    '.gif',
    '.ico',
    '.jpeg',
    '.jpg',
    '.pdf',
    '.png',
    '.ttf',
    '.woff',
    '.zip',
    '',
]



import argparse
import os
import re

from roverio.constants import DIRS_TO_IGNORE, FILES_TO_IGNORE


class PhoneEmailSearcherCli():
    def __init__(self):
        parser = argparse.ArgumentParser(
            description='Phone/Email Searcher recursively searches files for patterns that may match a phone or email.'
        )
        parser.add_argument(
            '--path',
            required=True,
            help='Where Phone/Email Searcher will search.'
        )
        parser.add_argument(
            '-p',
            '--phone',
            required=False,
            action='store_true',
            help='Search for phone numbers in the directory specified.'
        )
        parser.add_argument(
            '-e',
            '--email',
            required=False,
            action='store_true',
            help='Search for emails in the directory specified.'
        )
        parser.parse_args(namespace=self)

    def run(self):
        PhoneEmailSearcher.main(
            path=self.path,
            phone=self.phone,
            email=self.email,
        )


class PhoneEmailSearcher():
    def main(path, phone, email):
        """Run the tool and print results to console
        """
        if phone:
            phone_results = PhoneEmailSearcher.search_for_phone(path)
            for result in phone_results:
                print(result)
        if email:
            email_results = PhoneEmailSearcher.search_for_email(path)
            for result in email_results:
                print(result)

    def search_for_phone(path):
        """Search for files that may contain a phone number
        """
        # Matches a phone number as simple as `8015551234` or as complex as `+44 (801) 555-1234`
        # This is most likely too loose of a regex, but very forgiving and will catch weird edge cases
        phone_regex = re.compile(r'[0-9-+() ]{10,18}')

        # Scout for the search query in all subdirectories of the one specified
        phone_files = []
        for root, dirs, files in os.walk(path, topdown=True):
            dirs[:] = [directory for directory in dirs if directory not in DIRS_TO_IGNORE]
            for filename in files:
                filepath = os.path.join(root, filename)

                # Open each file and print the findings
                _, file_extension = os.path.splitext(filepath)
                if file_extension.lower() not in FILES_TO_IGNORE:
                    with open(filepath, 'r') as single_file:
                        for line_number, line in enumerate(single_file, 1):
                            data = phone_regex.findall(line)
                            for result in data:
                                if any(char.isdigit() for char in result):
                                    message = f'File: {filepath}\nResult: {line.strip()}\nLine: {line_number}\n'
                                    phone_files.append(message)
        return phone_files

    def search_for_email(path):
        """Search for files that may contain an email
        """
        # Losely matches email patterns of `anything@anything.anything` without spaces
        email_regex = re.compile(r'[^\s]+@[^\s]+\.[^\s]+')

        # Scout for the search query in all subdirectories of the one specified
        email_files = []
        for root, dirs, files in os.walk(path, topdown=True):
            dirs[:] = [directory for directory in dirs if directory not in DIRS_TO_IGNORE]
            for filename in files:
                filepath = os.path.join(root, filename)

                # Open each file and print the findings
                _, file_extension = os.path.splitext(filepath)
                if file_extension.lower() not in FILES_TO_IGNORE:
                    with open(filepath, 'r') as single_file:
                        for line_number, line in enumerate(single_file, 1):
                            data = email_regex.findall(line)
                            for result in data:
                                # Don't accidentally grab massive strings that aren't emails
                                if len(line) < 256:
                                    message = f'File: {filepath}\nResult: {line.strip()}\nLine: {line_number}\n'
                                    email_files.append(message)
        return email_files


def main():
    PhoneEmailSearcherCli().run()


if __name__ == '__main__':
    main()



import argparse
import os

from roverio.constants import DIRS_TO_IGNORE


class FileExtensionCLI():
    def __init__(self):
        parser = argparse.ArgumentParser(
            description='File Extension searches for all files in a path with the specified file extension.'
        )
        parser.add_argument(
            '-p',
            '--path',
            required=True,
            help='Where File Extension will search for files with the specified file extension.'
        )
        parser.add_argument(
            '-e',
            '--extension',
            required=True,
            help='The file extension to search a path for.'
        )
        parser.parse_args(namespace=self)

    def run(self):
        FileExtension.main(
            path=self.path,
            extension=self.extension,
        )


class FileExtension():
    @staticmethod
    def main(path, extension):
        """Run the tool and print results to console
        """
        files = FileExtension.search_file_extensions(path, extension)
        for filename in files:
            print(filename)

    @staticmethod
    def search_file_extensions(path, extension):
        """Search for files with a specific extension in the specified directory
        """
        file_extension_files = []
        for root, dirs, files in os.walk(path, topdown=True):
            dirs[:] = [directory for directory in dirs if directory not in DIRS_TO_IGNORE]
            for filename in files:
                if filename.endswith(extension):
                    file_extension_file = os.path.join(root, filename)
                    file_extension_files.append(file_extension_file)
        return file_extension_files


def main():
    FileExtensionCLI().run()


if __name__ == '__main__':
    main()



import argparse
import csv
import os
import re

from pretty_tables import PrettyTables

from roverio.constants import DIRS_TO_IGNORE

README_STRING = os.getenv('README_STRING', 'readme.md')


class Cli():
    def __init__(self):
        parser = argparse.ArgumentParser(description='Reads the contents of README files.')
        parser.add_argument(
            '-p',
            '--path',
            required=True,
            help='The path where the tool will search for README\'s.'
        )
        parser.add_argument(
            '-r',
            '--rules',
            required=True,
            help='The path to your rule text file.'
        )
        parser.add_argument(
            '-l',
            '--lazy',
            required=False,
            default=False,
            action='store_true',
            help='Match rules lazily (case-insensitive).'
        )
        parser.add_argument(
            '-c',
            '--create_csv',
            required=False,
            default=False,
            action='store_true',
            help='Save output to a CSV file.'
        )
        parser.add_argument(
            '--csv_path',
            required=False,
            default='readmy_readmes.csv',
            help='The file path where a CSV file will be saved. By default, it will be saved to the current directory.'  # noqa
        )
        parser.parse_args(namespace=self)

    def run(self):
        ReadmyReadmes.run_cli(
            path=self.path,
            rules=self.rules,
            lazy=self.lazy,
            create_csv=self.create_csv,
            csv_path=self.csv_path,
        )


class ReadmyReadmes():
    @staticmethod
    def run_cli(path, rules, create_csv=False, csv_path='readmy_readmes.csv', lazy=False):
        """Run this tool via CLI and print to console
        """
        readmes = ReadmyReadmes.iterate_readmes(path, rules, create_csv, csv_path, lazy)
        print(readmes)

    @staticmethod
    def iterate_readmes(path, rules, create_csv=False, csv_path='readmy_readmes.csv', lazy=False):
        """Iterate through README files looking for each rule.
        Build a table of data based on what is found.
        """
        rules = ReadmyReadmes._open_rules_file(rules)

        # Setup headers
        headers = ['README File']
        for rule in rules:
            headers.append(rule)

        # Setup rows
        rows = []
        readmes = ReadmyReadmes.find_readmes(path)
        for readme in readmes:
            readme_regex = re.compile(fr'{path}/(?P<readme>.+)')
            readme_path_short = readme_regex.search(readme)
            row = [readme_path_short['readme']]
            readme_contents = ReadmyReadmes._open_readme_file(readme)
            for rule in rules:
                row.append(ReadmyReadmes._check_rules_in_readme(readme_contents, rule, lazy))
            rows.append(row)
        sorted_rows = sorted(rows)

        # Setup Pretty Table
        table = PrettyTables.generate_table(
            headers=headers,
            rows=sorted_rows,
        )

        # Setup CSV (if elected)
        if create_csv:
            ReadmyReadmes._create_csv(headers, sorted_rows, csv_path)

        return table

    @staticmethod
    def _open_rules_file(rules):
        """Reads the contents of the rules file
        """
        with open(rules, 'r') as rule_file:
            rules = rule_file.read().split('\n')
        rules.remove('')  # Remove any blank items due to empty lines
        return rules

    @staticmethod
    def _open_readme_file(readme):
        """Reads the contents of a README file
        """
        with open(readme, 'r') as readme_file:
            readme_contents = readme_file.read()
        return readme_contents

    @staticmethod
    def _create_csv(headers, data, csv_path):
        """Create a CSV file
        """
        try:
            data.insert(0, headers)
            with open(csv_path, 'w') as csvfile:
                writer = csv.writer(csvfile)
                writer.writerows(data)
        except Exception as error:
            raise Exception(error)

    @staticmethod
    def find_readmes(path):
        """Walks a folder structure looking for README files and
        returns a list of the paths of each README found.
        """
        readme_list = []
        for root, dirs, files in os.walk(path, topdown=True):
            dirs[:] = [directory for directory in dirs if directory not in DIRS_TO_IGNORE]
            for filename in files:
                if README_STRING.lower() in filename.lower():
                    readme_path = f'{root}/{filename}'
                    readme_list.append(readme_path)

        if readme_list == []:
            raise FileNotFoundError('No README files were found with the specified path.')

        return readme_list

    @staticmethod
    def _check_rules_in_readme(readme, rule, lazy=False):
        """Checks if a rule exists in a README file and returns a boolean
        if the rule is found within the README file.
        """
        if lazy:
            if rule.lower() in readme.lower():
                return True
        if not lazy:
            if rule in readme:
                return True
        return False


def main():
    Cli().run()


if __name__ == '__main__':
    main()



import argparse
import os
import re


class SequentialRenamerCLI():
    def __init__(self):
        parser = argparse.ArgumentParser(
            description='Sequential Renamer recursively renames files in a directory in a sequential manner and prepends the parent folder name.'  # noqa
        )
        parser.add_argument(
            '-p',
            '--path',
            required=True,
            help='Where Sequential Renamer will recursively rename files it finds.'
        )
        parser.add_argument(
            '-f',
            '--force',
            required=False,
            action='store_true',
            help='Force changes which take permenant effect.'
        )
        parser.parse_args(namespace=self)

    def run(self):
        SequentialRenamer.main(
            path=self.path,
            force=self.force,
        )


class SequentialRenamer():
    @staticmethod
    def main(path, force=False):
        """Run the tool printing the results to console
        """
        print('Sequential Renamer in progress, this could take awhile depending on the number of items in your specified path...')  # noqa
        messages, files_updated = SequentialRenamer.rename_files(path, force)
        if force:
            print(f'Process complete, {files_updated} records were updated!')
        else:
            for message in messages:
                print(message)
            print(f'{files_updated} records will be updated when forced.')
            print('DRY RUN complete, run with the "--force" flag to actually rename files.')

    @staticmethod
    def rename_files(path, force=False):
        """Recursively rename files in a sequential manner, prepending the folder name to
        a seqential number that restarts in each folder

        Example output:
        /Users/jhammond/Downloads/Justin Skydive 2019/IMG_2462_proc_592015324.jpg  ->  justin-skydive-2019-0.jpg
        /Users/jhammond/Downloads/Justin Skydive 2019/IMG_2494_proc_592015326.jpg  ->  justin-skydive-2019-1.jpg
        /Users/jhammond/Downloads/Justin Skydive 2019/IMG_2514_proc_592015327.jpg  ->  justin-skydive-2019-2.jpg
        """  # noqa
        files_to_ignore = [
            '.ds_store',
        ]
        dirs_to_ignore = [
            'photos library',
            'photos library.photoslibrary',
        ]

        files_updated = 0
        messages = []
        for root, dirs, files in os.walk(path, topdown=True):
            files[:] = [filename for filename in files if filename.lower() not in files_to_ignore]
            dirs[:] = [directory for directory in dirs if directory.lower() not in dirs_to_ignore]
            for i, full_filename in enumerate(files):
                file_extension = os.path.splitext(full_filename)[1].lower()

                folder_name = os.path.basename(os.path.dirname(os.path.join(root, full_filename)))
                slugged_folder_name = folder_name.replace('_', '-').replace(' ', '-')

                files_updated += 1
                new_filename = (re.sub(r'[^0-9a-zA-Z-_]+', '', slugged_folder_name) + '-' + str(i) + file_extension).lower()  # noqa
                messages.append(os.path.join(root, full_filename) + '  ->  ' + new_filename)

                if force:
                    os.rename(os.path.join(root, full_filename), os.path.join(root, new_filename))
            print(messages)
        return messages, files_updated


def main():
    SequentialRenamerCLI().run()


if __name__ == '__main__':
    main()



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

REQUIREMENTS = [
    'pretty-tables == 1.*',
]

DEV_REQUIREMENTS = [
    'coveralls == 3.*',
    'flake8',
    'mock == 4.*',
    'pytest == 6.*',
    'pytest-cov == 2.*',
]

setuptools.setup(
    name='roverio',
    version='2.2.0',
    description='Rover IO is a suite of tools that traverses your directories and performs IO file operations.',  # noqa
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='http://github.com/justintime50/roverio',
    author='Justintime50',
    license='MIT',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=REQUIREMENTS,
    extras_require={
        'dev': DEV_REQUIREMENTS
    },
    entry_points={
        'console_scripts': [
            'roverio-file-extension = roverio.file_extension:main',
            'roverio-phone-email-searcher = roverio.phone_email_searcher:main',
            'roverio-readmy-readmes = roverio.readmy_readmes:main',
            'roverio-scout = roverio.scout:main',
            'roverio-secrets = roverio.secrets:main',
            'roverio-sequential-renamer = roverio.sequential_renamer:main',
        ]
    },
    python_requires='>=3.6',
)
